
# ChatSonic API, (Scalable ChatGPT Alternative with real time data) 



ChatSonic's Python SDK is the perfect solution for anyone looking to integrate an AI-powered Chatbot into their Python-based codebase. With real-time Google data support and a powerful engine that surpasses ChatGPT, ChatSonic's Python SDK is the perfect AI assistant and conversation partner. Easily access the power of ChatGPT API with this SDK and make your codebases smarter than ever. With ChatSonic's Python SDK, you can take your project to the next level.



## License


[![MIT License](https://img.shields.io/badge/License-MIT-green.svg)](https://choosealicense.com/licenses/mit/)
## Installation 

``` pip install chatsonic-py ```


## Usage :


```Python
from chatsonic import Conversation

chatsonic = Conversation(api_key="your-key-here",enable_memory=True)
reply = chatsonic.send_message(message="Hello")
print(reply)

```



## Documentation

[Documentation](https://linktodocumentation)


## Feedback

If you have any feedback, please reach out to us at support@writesonic.com

